package com.smppw.analysis.application.service.position;

import cn.hutool.core.map.MapUtil;
import cn.hutool.core.text.CharSequenceUtil;
import com.smppw.analysis.application.dto.position.BaseParams;
import org.springframework.stereotype.Component;

import java.util.Map;

@Component
public class BizHandlerFactor {
    private static final BizHandler<BaseParams, Object> EMPTY = p -> null;
    private static final Map<String, BizHandler<? extends BaseParams, ?>> BIZ_HANDLER_STRATEGY = MapUtil.newHashMap(32);

    public BizHandlerFactor(Map<String, BizHandler<? extends BaseParams, ?>> bizHandlerMap) {
        BIZ_HANDLER_STRATEGY.putAll(bizHandlerMap);
    }

    @SuppressWarnings("unchecked")
    public <P extends BaseParams, R> BizHandler<P, R> getBizHandlerInstance(String strategyKey) {
        BizHandler<P, R> empty = (BizHandler<P, R>) EMPTY;
        if (CharSequenceUtil.isBlank(strategyKey)) {
            return empty;
        }
        BizHandler<? extends BaseParams, ?> bizHandler = BIZ_HANDLER_STRATEGY.get(strategyKey);
        if (bizHandler == null) {
            return empty;
        }
        try {
            return (BizHandler<P, R>) bizHandler;
        } catch (Exception e) {
            return empty;
        }
    }
}
